@@ -1,13 +1,18 @@
 from __future__ import unicode_literals
 
 import copy
+import os
 from contextlib import contextmanager
+from dvc.utils.compat import FileNotFoundError
 
 from funcy import merge
 
 from .local import DependencyLOCAL
 from dvc.external_repo import external_repo
 from dvc.utils.compat import str
+from dvc.exceptions import OutputNotFoundError
+from dvc.exceptions import PathMissingError
+from dvc.utils.fs import fs_copy
 
 
 class DependencyREPO(DependencyLOCAL):
@@ -72,10 +77,42 @@ class DependencyREPO(DependencyLOCAL):
 
         return out
 
+    @staticmethod
+    def _is_git_file(repo, path):
+        if not os.path.isabs(path):
+            try:
+                output = repo.find_out_by_relpath(path)
+                if not output.use_cache:
+                    return True
+            except OutputNotFoundError:
+                return True
+        return False
+
+    def _copy_if_git_file(self, to_path):
+        src_path = self.def_path
+        with self._make_repo(
+            cache_dir=self.repo.cache.local.cache_dir
+        ) as repo:
+            if not self._is_git_file(repo, src_path):
+                return False
+
+            src_full_path = os.path.join(repo.root_dir, src_path)
+            dst_full_path = os.path.abspath(to_path)
+            fs_copy(src_full_path, dst_full_path)
+        return True
+
     def download(self, to):
-        out = self.fetch()
-        to.info = copy.copy(out.info)
-        to.checkout()
+        try:
+            if self._copy_if_git_file(to.fspath):
+                return
+
+            out = self.fetch()
+            to.info = copy.copy(out.info)
+            to.checkout()
+        except (FileNotFoundError):
+            raise PathMissingError(
+                self.def_path, self.def_repo[self.PARAM_URL]
+            )
 
     def update(self):
         with self._make_repo(rev_lock=None) as repo:
